<?php declare(strict_types=1);
/**
 * JTL Plugin
 * Copyright (C) 2011 - 2020 Andreas Petermann
 *
 * PHP version 7.2+
 *
 * @copyright css-umsetzung
 * @author Andreas Petermann <info@css-umsetzung.de>
 * @package css_vatSelect
 * @license GNU
 * @version 1.00
 *
 */

namespace Plugin\css_vatSelect;

use JTL\Alert\Alert;
use JTL\Catalog\Category\Kategorie;
use JTL\Catalog\Product\Artikel;
use JTL\Events\Dispatcher;
use JTL\Events\Event;
use JTL\Helpers\Form;
use JTL\Helpers\Request;
use JTL\Link\LinkInterface;
use JTL\Plugin\Bootstrapper;
use JTL\Shop;
use JTL\Smarty\JTLSmarty;
use Plugin\css_vatSelect\src\cssPlugin;
/**
 * Class Bootstrap
 * @package Plugin\jtl_test
 */
class Bootstrap extends Bootstrapper
{
    /**
     * @var TestHelper
     */
    private $cssPlugin;

    private const TEST_CRON_JOB = 'jtl_test_cron';

    /**
     * @inheritdoc
     */
    public function boot(Dispatcher $dispatcher)
    {

        parent::boot($dispatcher);
            $plugin = $this->getPlugin();

        if (Shop::isFrontend() === true || (isset($_REQUEST['kPlugin']) &&  $plugin->getID() == (int) $_REQUEST['kPlugin'])) {

            $this->cssPlugin = src\cssPlugin\cssPlugin::getInstance(
                $plugin,
                $this->getDB(),
                $this->getCache()
            );
        }
        if (Shop::isFrontend() === true) {
            $cfg = $this->cssPlugin->getConfig();
            if($cfg->pluginActive=='N') return;

            $dispatcher->listen('shop.hook.' . \HOOK_SMARTY_OUTPUTFILTER, function () use ($plugin) {
                $this->cssPlugin->hookSmartyOutputfilter();
            });
            $dispatcher->listen('shop.hook.' . \HOOK_LETZTERINCLUDE_INC, function (array $args) use ($plugin) {
                $this->cssPlugin->hookLetzterincludeInc($args);
            });
            $dispatcher->listen('shop.hook.' . \HOOK_IO_HANDLE_REQUEST, function (array $args) use ($plugin) {
                $this->cssPlugin->hookIoHandleRequest($args);
            });
            $dispatcher->listen('shop.hook.' . \HOOK_CSS_JS_LIST, function (array $args) use ($plugin) {
                $this->cssPlugin->hookCssJsList($args);
            });

        }  else {

#            require_once $plugin->getPaths()->getBasePath() . 'includes/defines_inc.php';
#            $this->admin = new Admin($this->getDB(), Shop::Container()->getBackendLogService());
        }

    }        

    /**
     * @inheritdoc
     */
    public function installed()
    {
        $plugin  = $this->getPlugin();
#        $minify          = new MinifyService();
#        $minify->flushCache();
        Shop::Cache()->flushTags(array(CACHING_GROUP_TEMPLATE,CACHING_GROUP_PLUGIN,'cache_'.$plugin->getPluginID()));
        parent::installed();
    }

    /**
     * @inheritdoc
     */
    public function updated($oldVersion, $newVersion)
    {
        $plugin  = $this->getPlugin();
#        $minify          = new MinifyService();
#        $minify->flushCache();
        Shop::Cache()->flushTags(array(CACHING_GROUP_TEMPLATE,CACHING_GROUP_PLUGIN,'cache_'.$plugin->getPluginID()));
        \error_log('updated from ' . $oldVersion . ' to ' . $newVersion);
    }

    /**
     * @inheritdoc
     */
    public function uninstalled(bool $deleteData = true)
    {
        if($deleteData === true) {
            $this->getDB()->query('DROP TABLE IF EXISTS `css_vatSelectConfig`', 3);
        }
        parent::uninstalled($deleteData);
        $plugin  = $this->getPlugin();
#        $minify          = new MinifyService();
#        $minify->flushCache();
        Shop::Cache()->flushTags(array(CACHING_GROUP_TEMPLATE,CACHING_GROUP_PLUGIN,'cache_'.$plugin->getPluginID()));
    }
}
